# frozen_string_literal: true

module BankOfBaku
  module Configuration
    VALID_OPTIONS_KEYS = %i[endpoint username password user_agent typhoeus_options].freeze
    DEFAULT_USER_AGENT = "BankOfBaku Ruby Gem #{BankOfBaku::VERSION}"

    attr_accessor(*VALID_OPTIONS_KEYS)

    def self.extended(base)
      base.reset
    end

    def configure
      yield self
    end

    def reset
      VALID_OPTIONS_KEYS.each do |key|
        send("#{key}=", nil)
      end
      self.user_agent = DEFAULT_USER_AGENT
      self.typhoeus_options = {}
    end

    def credentials
      {
        userName: username,
        password: password,
        language: 'en'
      }
    end
  end
end
